==> haskell-hls-hlint-plugin-2.0.0.0-37-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hls-hlint-plugin.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hls-hlint-plugin
version:              2.0.0.0
visibility:           public
id:                   hls-hlint-plugin-2.0.0.0-GfrbcblbnEtLZ78CiQyBnG
key:                  hls-hlint-plugin-2.0.0.0-GfrbcblbnEtLZ78CiQyBnG
license:              Apache-2.0
copyright:            The Haskell IDE Team
maintainer:           atreyu.bbb@gmail.com
author:               The Haskell IDE Team
synopsis:             Hlint integration plugin with Haskell Language Server
description:
    Please see the README on GitHub at <https://github.com/haskell/haskell-language-server#readme>

category:             Development
abi:                  7f82f13bec7b1635cff44d490845c682
exposed:              True
exposed-modules:      Ide.Plugin.Hlint
import-dirs:          /usr/lib/ghc-9.4.8/site-local/hls-hlint-plugin-2.0.0.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/hls-hlint-plugin-2.0.0.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/hls-hlint-plugin-2.0.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hls-hlint-plugin
hs-libraries:         HShls-hlint-plugin-2.0.0.0-GfrbcblbnEtLZ78CiQyBnG
depends:
    Diff-0.4.1-LH1ky1AbixJl32mO74dkD
    aeson-2.1.2.1-G4Y2VMvw6jlHlUlOzfqhge
    apply-refact-0.12.0.0-Dly81JVHXAB1Opz10SQMZ0 base-4.17.2.1
    binary-0.8.9.1 bytestring-0.11.5.3 containers-0.6.7
    data-default-0.7.1.1-HuI8bY4bNR4F11jcRg6vOi deepseq-1.4.8.0
    directory-1.3.7.1 extra-1.7.16-LRPaj0kKdYhA5DC3OzySjK
    filepath-1.4.2.2 ghc-9.4.8 ghc-boot-9.4.8
    ghc-exactprint-1.6.1-C0Oiqfv79rb7N3Oe6rciyx
    ghc-lib-parser-ex-9.4.0.0-GkELVMqtFZI6ww5YwHbXrH
    ghcide-2.0.0.0-2tJOXekO5UuJXWQkwF4Jxw
    hashable-1.4.4.0-nWtkxUvx9i9tMRJKCZgnw
    hlint-3.5-JqdrmVwtxVE1BkvI1AvHmQ
    hls-plugin-api-2.0.0.0-DpPUjugBEsF4W1sa2QAW6E
    lens-5.2.3-XbCdaNVqtRCIbafw90cRt lsp-1.6.0.0-7NVcPrTRIHQ2yUGyXsP7lb
    refact-0.3.0.2-KPJC6T8FqM8EMkV2k8FDeA
    regex-tdfa-1.3.2.3-ATHs20GYS4zCnV1KwOyBL0 stm-2.5.1.0
    temporary-1.3-5ukCxB0doMQ964otfCXv0z text-2.0.2
    transformers-0.5.6.2
    unordered-containers-0.2.20-1zjZuvvQz6A9v2Utwl5wnX

haddock-interfaces:
    /usr/share/doc/haskell-hls-hlint-plugin/html/hls-hlint-plugin.haddock

haddock-html:         /usr/share/doc/haskell-hls-hlint-plugin/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hls-hlint-plugin-2.0.0.0-38-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hls-hlint-plugin.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hls-hlint-plugin
version:              2.0.0.0
visibility:           public
id:                   hls-hlint-plugin-2.0.0.0-BZz8LcDeTYiHNRKnr4PrMM
key:                  hls-hlint-plugin-2.0.0.0-BZz8LcDeTYiHNRKnr4PrMM
license:              Apache-2.0
copyright:            The Haskell IDE Team
maintainer:           atreyu.bbb@gmail.com
author:               The Haskell IDE Team
synopsis:             Hlint integration plugin with Haskell Language Server
description:
    Please see the README on GitHub at <https://github.com/haskell/haskell-language-server#readme>

category:             Development
abi:                  8dedffedd7f47504a26fa74a5f56ba6c
exposed:              True
exposed-modules:      Ide.Plugin.Hlint
import-dirs:          /usr/lib/ghc-9.4.8/site-local/hls-hlint-plugin-2.0.0.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/hls-hlint-plugin-2.0.0.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/hls-hlint-plugin-2.0.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hls-hlint-plugin
hs-libraries:         HShls-hlint-plugin-2.0.0.0-BZz8LcDeTYiHNRKnr4PrMM
depends:
    Diff-0.4.1-644Hl6gJ6c41D4iXUJ55VB
    aeson-2.1.2.1-Ex7WnNUT1auEGSF1Md5zyM
    apply-refact-0.12.0.0-DypTYrFyW4oCFfgp2cCK9J base-4.17.2.1
    binary-0.8.9.1 bytestring-0.11.5.3 containers-0.6.7
    data-default-0.7.1.1-HuI8bY4bNR4F11jcRg6vOi deepseq-1.4.8.0
    directory-1.3.7.1 extra-1.7.16-BgNJJwZ4wAmKWLSYOLNV8h
    filepath-1.4.2.2 ghc-9.4.8 ghc-boot-9.4.8
    ghc-exactprint-1.6.1-5sGAth5bBxa2Vfm8GrpoM0
    ghc-lib-parser-ex-9.4.0.0-KvHGJYiGFjBKYCDUcg4otf
    ghcide-2.0.0.0-9mqK64UxEuy11axeLO8nOU
    hashable-1.4.4.0-G3df7eBPFu1LRujEcYqf5c
    hlint-3.5-JP5l0AKiSlF8ulphq2JG4D
    hls-plugin-api-2.0.0.0-2wOGvVnkqhWI6va0WcbmBZ
    lens-5.2.3-3fSsMRucgnZ99PomxyWs7a
    lsp-1.6.0.0-JytyfPtRXjzE8uTsBKsXUD
    refact-0.3.0.2-KPJC6T8FqM8EMkV2k8FDeA
    regex-tdfa-1.3.2.3-1KOOZGaJQ2ADpVIAJeQf05 stm-2.5.1.0
    temporary-1.3-G7P6lNH75E76cAGC2vHtSc text-2.0.2
    transformers-0.5.6.2
    unordered-containers-0.2.20-EFINKuAnn2VCsrMAVqSNI6

haddock-interfaces:
    /usr/share/doc/haskell-hls-hlint-plugin/html/hls-hlint-plugin.haddock

haddock-html:         /usr/share/doc/haskell-hls-hlint-plugin/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
